Class: UnivapayClientSdk::CheckoutInstallmentCardProcessor

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/checkout_installment_card_processor.rb

Overview

Card-processor capabilities available for installment payments.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(revolving: SKIP, fixed_cycle: SKIP, additional_properties: nil) ⇒ CheckoutInstallmentCardProcessor

Returns a new instance of CheckoutInstallmentCardProcessor.



41
42
43
44
45
46
47
48
49
# File 'lib/univapay_client_sdk/models/checkout_installment_card_processor.rb', line 41

def initialize(revolving: SKIP, fixed_cycle: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @revolving = revolving unless revolving == SKIP
  @fixed_cycle = fixed_cycle unless fixed_cycle == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#fixed_cycleTrueClass | FalseClass

Whether fixed-cycle installment payments are allowed.

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/univapay_client_sdk/models/checkout_installment_card_processor.rb', line 18

def fixed_cycle
  @fixed_cycle
end

#revolvingTrueClass | FalseClass

Whether revolving installment payments are allowed.

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/univapay_client_sdk/models/checkout_installment_card_processor.rb', line 14

def revolving
  @revolving
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/univapay_client_sdk/models/checkout_installment_card_processor.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  revolving = hash.key?('revolving') ? hash['revolving'] : SKIP
  fixed_cycle = hash.key?('fixed_cycle') ? hash['fixed_cycle'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CheckoutInstallmentCardProcessor.new(revolving: revolving,
                                       fixed_cycle: fixed_cycle,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/univapay_client_sdk/models/checkout_installment_card_processor.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['revolving'] = 'revolving'
  @_hash['fixed_cycle'] = 'fixed_cycle'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/univapay_client_sdk/models/checkout_installment_card_processor.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/univapay_client_sdk/models/checkout_installment_card_processor.rb', line 29

def self.optionals
  %w[
    revolving
    fixed_cycle
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/univapay_client_sdk/models/checkout_installment_card_processor.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} revolving: #{@revolving.inspect}, fixed_cycle: #{@fixed_cycle.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/univapay_client_sdk/models/checkout_installment_card_processor.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} revolving: #{@revolving}, fixed_cycle: #{@fixed_cycle},"\
  " additional_properties: #{@additional_properties}>"
end