Class: UnivapayClientSdk::CreateCustomerIdResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/create_customer_id_response.rb

Overview

Response payload returned after deriving a deterministic customer ID.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(customer_id: SKIP, additional_properties: nil) ⇒ CreateCustomerIdResponse

Returns a new instance of CreateCustomerIdResponse.



36
37
38
39
40
41
42
# File 'lib/univapay_client_sdk/models/create_customer_id_response.rb', line 36

def initialize(customer_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @customer_id = customer_id unless customer_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#customer_idUUID | String

Deterministic UUID derived from the store and the supplied local customer_id. Identical for repeated calls with the same inputs.

Returns:

  • (UUID | String)


15
16
17
# File 'lib/univapay_client_sdk/models/create_customer_id_response.rb', line 15

def customer_id
  @customer_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/univapay_client_sdk/models/create_customer_id_response.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  customer_id = hash.key?('customer_id') ? hash['customer_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreateCustomerIdResponse.new(customer_id: customer_id,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/univapay_client_sdk/models/create_customer_id_response.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['customer_id'] = 'customer_id'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/univapay_client_sdk/models/create_customer_id_response.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/univapay_client_sdk/models/create_customer_id_response.rb', line 25

def self.optionals
  %w[
    customer_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
75
# File 'lib/univapay_client_sdk/models/create_customer_id_response.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



64
65
66
67
68
# File 'lib/univapay_client_sdk/models/create_customer_id_response.rb', line 64

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id}, additional_properties:"\
  " #{@additional_properties}>"
end