Class: UnivapayClientSdk::DirectDebitMerchantConfiguration

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb

Overview

The merchant's effective direct debit configuration.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(legacy_id: SKIP, enabled: SKIP, debit_date: SKIP, consignor_code: SKIP, classifier: SKIP, signature: SKIP, additional_properties: nil) ⇒ DirectDebitMerchantConfiguration

Returns a new instance of DirectDebitMerchantConfiguration.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 66

def initialize(legacy_id: SKIP, enabled: SKIP, debit_date: SKIP,
               consignor_code: SKIP, classifier: SKIP, signature: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @legacy_id = legacy_id unless legacy_id == SKIP
  @enabled = enabled unless enabled == SKIP
  @debit_date = debit_date unless debit_date == SKIP
  @consignor_code = consignor_code unless consignor_code == SKIP
  @classifier = classifier unless classifier == SKIP
  @signature = signature unless signature == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#classifierString

Transfer classification code (区分) agreed with the collecting bank.

Returns:

  • (String)


30
31
32
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 30

def classifier
  @classifier
end

#consignor_codeString

Consignor code (委託者コード) assigned by the collecting bank.

Returns:

  • (String)


26
27
28
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 26

def consignor_code
  @consignor_code
end

#debit_dateDirectDebitDebitDate

Monthly debit cycle — funds are pulled on either the 14th or the 27th.



22
23
24
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 22

def debit_date
  @debit_date
end

#enabledTrueClass | FalseClass

Whether direct debit is enabled for this merchant.

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 18

def enabled
  @enabled
end

#legacy_idString

Identifier of the merchant in the legacy direct debit system.

Returns:

  • (String)


14
15
16
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 14

def legacy_id
  @legacy_id
end

#signatureString

Name printed on the consumer's bank statement (印字名), in half-width katakana.

Returns:

  • (String)


35
36
37
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 35

def signature
  @signature
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 82

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  legacy_id = hash.key?('legacy_id') ? hash['legacy_id'] : SKIP
  enabled = hash.key?('enabled') ? hash['enabled'] : SKIP
  debit_date = hash.key?('debit_date') ? hash['debit_date'] : SKIP
  consignor_code =
    hash.key?('consignor_code') ? hash['consignor_code'] : SKIP
  classifier = hash.key?('classifier') ? hash['classifier'] : SKIP
  signature = hash.key?('signature') ? hash['signature'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DirectDebitMerchantConfiguration.new(legacy_id: legacy_id,
                                       enabled: enabled,
                                       debit_date: debit_date,
                                       consignor_code: consignor_code,
                                       classifier: classifier,
                                       signature: signature,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



38
39
40
41
42
43
44
45
46
47
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 38

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['legacy_id'] = 'legacy_id'
  @_hash['enabled'] = 'enabled'
  @_hash['debit_date'] = 'debit_date'
  @_hash['consignor_code'] = 'consignor_code'
  @_hash['classifier'] = 'classifier'
  @_hash['signature'] = 'signature'
  @_hash
end

.nullablesObject

An array for nullable fields



62
63
64
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 62

def self.nullables
  []
end

.optionalsObject

An array for optional fields



50
51
52
53
54
55
56
57
58
59
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 50

def self.optionals
  %w[
    legacy_id
    enabled
    debit_date
    consignor_code
    classifier
    signature
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



120
121
122
123
124
125
126
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 120

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} legacy_id: #{@legacy_id.inspect}, enabled: #{@enabled.inspect}, debit_date:"\
  " #{@debit_date.inspect}, consignor_code: #{@consignor_code.inspect}, classifier:"\
  " #{@classifier.inspect}, signature: #{@signature.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



112
113
114
115
116
117
# File 'lib/univapay_client_sdk/models/direct_debit_merchant_configuration.rb', line 112

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} legacy_id: #{@legacy_id}, enabled: #{@enabled}, debit_date: #{@debit_date},"\
  " consignor_code: #{@consignor_code}, classifier: #{@classifier}, signature: #{@signature},"\
  " additional_properties: #{@additional_properties}>"
end