Class: UnivapayClientSdk::TokenCreateQrScanData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/token_create_qr_scan_data.rb

Overview

Token Create Qr Scan Data schema.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(scanned_qr:, additional_properties: nil) ⇒ TokenCreateQrScanData

Returns a new instance of TokenCreateQrScanData.



36
37
38
39
40
41
42
# File 'lib/univapay_client_sdk/models/token_create_qr_scan_data.rb', line 36

def initialize(scanned_qr:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @scanned_qr = scanned_qr
  @additional_properties = additional_properties
end

Instance Attribute Details

#scanned_qrString

The QR/barcode payload scanned from the customer's payment app (Customer-Presented Mode). Only valid when type is one_time — the server rejects subscription/recurring token types for this payment type.

Returns:

  • (String)


17
18
19
# File 'lib/univapay_client_sdk/models/token_create_qr_scan_data.rb', line 17

def scanned_qr
  @scanned_qr
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/univapay_client_sdk/models/token_create_qr_scan_data.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  scanned_qr = hash.key?('scanned_qr') ? hash['scanned_qr'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TokenCreateQrScanData.new(scanned_qr: scanned_qr,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/univapay_client_sdk/models/token_create_qr_scan_data.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['scanned_qr'] = 'scanned_qr'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/univapay_client_sdk/models/token_create_qr_scan_data.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



27
28
29
# File 'lib/univapay_client_sdk/models/token_create_qr_scan_data.rb', line 27

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



65
66
67
68
69
70
71
72
73
74
75
# File 'lib/univapay_client_sdk/models/token_create_qr_scan_data.rb', line 65

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.scanned_qr,
                                 ->(val) { val.instance_of? String })
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['scanned_qr'],
                        ->(val) { val.instance_of? String })
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/univapay_client_sdk/models/token_create_qr_scan_data.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} scanned_qr: #{@scanned_qr.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/univapay_client_sdk/models/token_create_qr_scan_data.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} scanned_qr: #{@scanned_qr}, additional_properties:"\
  " #{@additional_properties}>"
end