Class: UnivapayClientSdk::TokenResponseQrScanData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/token_response_qr_scan_data.rb

Overview

Token Response Qr Scan Data schema.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(brand:, additional_properties: nil) ⇒ TokenResponseQrScanData

Returns a new instance of TokenResponseQrScanData.



38
39
40
41
42
43
44
# File 'lib/univapay_client_sdk/models/token_response_qr_scan_data.rb', line 38

def initialize(brand:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @brand = brand
  @additional_properties = additional_properties
end

Instance Attribute Details

#brandString

QR-CPM brand detected from the scanned code (e.g. pay_pay, we_chat, qq, line_pay, au_pay, alipay_china). This is an open value set — new brands may appear without notice. Returned as null when the scanned code could not be parsed into a known brand.

Returns:

  • (String)


17
18
19
# File 'lib/univapay_client_sdk/models/token_response_qr_scan_data.rb', line 17

def brand
  @brand
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/univapay_client_sdk/models/token_response_qr_scan_data.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  brand = hash.key?('brand') ? hash['brand'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TokenResponseQrScanData.new(brand: brand,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/univapay_client_sdk/models/token_response_qr_scan_data.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['brand'] = 'brand'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
35
36
# File 'lib/univapay_client_sdk/models/token_response_qr_scan_data.rb', line 32

def self.nullables
  %w[
    brand
  ]
end

.optionalsObject

An array for optional fields



27
28
29
# File 'lib/univapay_client_sdk/models/token_response_qr_scan_data.rb', line 27

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



67
68
69
70
71
72
73
74
75
76
77
# File 'lib/univapay_client_sdk/models/token_response_qr_scan_data.rb', line 67

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.brand,
                                 ->(val) { val.instance_of? String })
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['brand'],
                        ->(val) { val.instance_of? String })
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/univapay_client_sdk/models/token_response_qr_scan_data.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} brand: #{@brand.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
# File 'lib/univapay_client_sdk/models/token_response_qr_scan_data.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} brand: #{@brand}, additional_properties: #{@additional_properties}>"
end