Class: UnivapayClientSdk::CheckoutBankTransferConfiguration
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UnivapayClientSdk::CheckoutBankTransferConfiguration
- Defined in:
- lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb
Overview
Bank transfer (振込) payment settings applied to checkout.
Instance Attribute Summary collapse
-
#automatic_extension_enabled ⇒ TrueClass | FalseClass
Whether payment deadlines are extended automatically.
-
#charge_expired_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a bank transfer charge expires.
-
#charge_request_canceled_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a requested bank transfer charge is canceled.
-
#charge_request_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a bank transfer charge is requested.
-
#default_extension_period ⇒ String
ISO-8601 duration by which a payment deadline is extended by default.
-
#deposit_exceeded_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a deposit exceeds the requested amount.
-
#deposit_insufficient_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a deposit is insufficient.
-
#deposit_received_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a deposit is received.
-
#enabled ⇒ TrueClass | FalseClass
Whether bank transfer payments are enabled.
-
#expiration ⇒ String
ISO-8601 duration before a bank transfer payment expires.
-
#expiration_time_shift ⇒ ExpirationTimeShift
Time-of-day override applied when calculating expirations, shared by convenience-store and bank-transfer configuration.
-
#extension_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a payment deadline is extended.
-
#match_amount ⇒ CheckoutBankTransferMatchAmount
Deposit-matching policy applied to bank transfer payments.
-
#maximum_extension_period ⇒ String
ISO-8601 duration for the maximum allowed extension.
-
#remind_notification_enabled ⇒ TrueClass | FalseClass
Whether reminder notifications are sent before a payment deadline.
-
#remind_notification_period ⇒ String
ISO-8601 duration before expiration at which a reminder notification is sent.
-
#virtual_bank_accounts_fetch_count ⇒ Integer
Number of virtual bank accounts provisioned per replenishment.
-
#virtual_bank_accounts_threshold ⇒ Integer
Number of unused virtual bank accounts that triggers provisioning of additional accounts.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled: SKIP, match_amount: SKIP, expiration: SKIP, expiration_time_shift: SKIP, virtual_bank_accounts_threshold: SKIP, virtual_bank_accounts_fetch_count: SKIP, default_extension_period: SKIP, maximum_extension_period: SKIP, automatic_extension_enabled: SKIP, charge_request_notification_enabled: SKIP, charge_request_canceled_notification_enabled: SKIP, charge_expired_notification_enabled: SKIP, deposit_received_notification_enabled: SKIP, deposit_insufficient_notification_enabled: SKIP, deposit_exceeded_notification_enabled: SKIP, extension_notification_enabled: SKIP, remind_notification_period: SKIP, remind_notification_enabled: SKIP, additional_properties: nil) ⇒ CheckoutBankTransferConfiguration
constructor
A new instance of CheckoutBankTransferConfiguration.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled: SKIP, match_amount: SKIP, expiration: SKIP, expiration_time_shift: SKIP, virtual_bank_accounts_threshold: SKIP, virtual_bank_accounts_fetch_count: SKIP, default_extension_period: SKIP, maximum_extension_period: SKIP, automatic_extension_enabled: SKIP, charge_request_notification_enabled: SKIP, charge_request_canceled_notification_enabled: SKIP, charge_expired_notification_enabled: SKIP, deposit_received_notification_enabled: SKIP, deposit_insufficient_notification_enabled: SKIP, deposit_exceeded_notification_enabled: SKIP, extension_notification_enabled: SKIP, remind_notification_period: SKIP, remind_notification_enabled: SKIP, additional_properties: nil) ⇒ CheckoutBankTransferConfiguration
Returns a new instance of CheckoutBankTransferConfiguration.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 151 def initialize(enabled: SKIP, match_amount: SKIP, expiration: SKIP, expiration_time_shift: SKIP, virtual_bank_accounts_threshold: SKIP, virtual_bank_accounts_fetch_count: SKIP, default_extension_period: SKIP, maximum_extension_period: SKIP, automatic_extension_enabled: SKIP, charge_request_notification_enabled: SKIP, charge_request_canceled_notification_enabled: SKIP, charge_expired_notification_enabled: SKIP, deposit_received_notification_enabled: SKIP, deposit_insufficient_notification_enabled: SKIP, deposit_exceeded_notification_enabled: SKIP, extension_notification_enabled: SKIP, remind_notification_period: SKIP, remind_notification_enabled: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @enabled = enabled unless enabled == SKIP @match_amount = match_amount unless match_amount == SKIP @expiration = expiration unless expiration == SKIP @expiration_time_shift = expiration_time_shift unless expiration_time_shift == SKIP unless virtual_bank_accounts_threshold == SKIP @virtual_bank_accounts_threshold = virtual_bank_accounts_threshold end unless virtual_bank_accounts_fetch_count == SKIP @virtual_bank_accounts_fetch_count = virtual_bank_accounts_fetch_count end @default_extension_period = default_extension_period unless default_extension_period == SKIP @maximum_extension_period = maximum_extension_period unless maximum_extension_period == SKIP unless automatic_extension_enabled == SKIP @automatic_extension_enabled = automatic_extension_enabled end unless charge_request_notification_enabled == SKIP @charge_request_notification_enabled = charge_request_notification_enabled end unless charge_request_canceled_notification_enabled == SKIP @charge_request_canceled_notification_enabled = charge_request_canceled_notification_enabled end unless charge_expired_notification_enabled == SKIP @charge_expired_notification_enabled = charge_expired_notification_enabled end unless deposit_received_notification_enabled == SKIP @deposit_received_notification_enabled = deposit_received_notification_enabled end unless deposit_insufficient_notification_enabled == SKIP @deposit_insufficient_notification_enabled = deposit_insufficient_notification_enabled end unless deposit_exceeded_notification_enabled == SKIP @deposit_exceeded_notification_enabled = deposit_exceeded_notification_enabled end unless extension_notification_enabled == SKIP @extension_notification_enabled = extension_notification_enabled end unless remind_notification_period == SKIP @remind_notification_period = remind_notification_period end unless remind_notification_enabled == SKIP @remind_notification_enabled = remind_notification_enabled end @additional_properties = additional_properties end |
Instance Attribute Details
#automatic_extension_enabled ⇒ TrueClass | FalseClass
Whether payment deadlines are extended automatically.
48 49 50 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 48 def automatic_extension_enabled @automatic_extension_enabled end |
#charge_expired_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a bank transfer charge expires.
61 62 63 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 61 def charge_expired_notification_enabled @charge_expired_notification_enabled end |
#charge_request_canceled_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a requested bank transfer charge is canceled.
57 58 59 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 57 def charge_request_canceled_notification_enabled @charge_request_canceled_notification_enabled end |
#charge_request_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a bank transfer charge is requested.
52 53 54 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 52 def charge_request_notification_enabled @charge_request_notification_enabled end |
#default_extension_period ⇒ String
ISO-8601 duration by which a payment deadline is extended by default.
40 41 42 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 40 def default_extension_period @default_extension_period end |
#deposit_exceeded_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a deposit exceeds the requested amount.
74 75 76 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 74 def deposit_exceeded_notification_enabled @deposit_exceeded_notification_enabled end |
#deposit_insufficient_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a deposit is insufficient.
69 70 71 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 69 def deposit_insufficient_notification_enabled @deposit_insufficient_notification_enabled end |
#deposit_received_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a deposit is received.
65 66 67 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 65 def deposit_received_notification_enabled @deposit_received_notification_enabled end |
#enabled ⇒ TrueClass | FalseClass
Whether bank transfer payments are enabled.
14 15 16 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 14 def enabled @enabled end |
#expiration ⇒ String
ISO-8601 duration before a bank transfer payment expires.
22 23 24 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 22 def expiration @expiration end |
#expiration_time_shift ⇒ ExpirationTimeShift
Time-of-day override applied when calculating expirations, shared by convenience-store and bank-transfer configuration.
27 28 29 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 27 def expiration_time_shift @expiration_time_shift end |
#extension_notification_enabled ⇒ TrueClass | FalseClass
Whether a notification is sent when a payment deadline is extended.
78 79 80 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 78 def extension_notification_enabled @extension_notification_enabled end |
#match_amount ⇒ CheckoutBankTransferMatchAmount
Deposit-matching policy applied to bank transfer payments.
18 19 20 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 18 def match_amount @match_amount end |
#maximum_extension_period ⇒ String
ISO-8601 duration for the maximum allowed extension.
44 45 46 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 44 def maximum_extension_period @maximum_extension_period end |
#remind_notification_enabled ⇒ TrueClass | FalseClass
Whether reminder notifications are sent before a payment deadline.
87 88 89 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 87 def remind_notification_enabled @remind_notification_enabled end |
#remind_notification_period ⇒ String
ISO-8601 duration before expiration at which a reminder notification is sent.
83 84 85 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 83 def remind_notification_period @remind_notification_period end |
#virtual_bank_accounts_fetch_count ⇒ Integer
Number of virtual bank accounts provisioned per replenishment.
36 37 38 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 36 def virtual_bank_accounts_fetch_count @virtual_bank_accounts_fetch_count end |
#virtual_bank_accounts_threshold ⇒ Integer
Number of unused virtual bank accounts that triggers provisioning of additional accounts.
32 33 34 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 32 def virtual_bank_accounts_threshold @virtual_bank_accounts_threshold end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 229 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash.key?('enabled') ? hash['enabled'] : SKIP match_amount = hash.key?('match_amount') ? hash['match_amount'] : SKIP expiration = hash.key?('expiration') ? hash['expiration'] : SKIP expiration_time_shift = ExpirationTimeShift.from_hash(hash['expiration_time_shift']) if hash['expiration_time_shift'] virtual_bank_accounts_threshold = hash.key?('virtual_bank_accounts_threshold') ? hash['virtual_bank_accounts_threshold'] : SKIP virtual_bank_accounts_fetch_count = hash.key?('virtual_bank_accounts_fetch_count') ? hash['virtual_bank_accounts_fetch_count'] : SKIP default_extension_period = hash.key?('default_extension_period') ? hash['default_extension_period'] : SKIP maximum_extension_period = hash.key?('maximum_extension_period') ? hash['maximum_extension_period'] : SKIP automatic_extension_enabled = hash.key?('automatic_extension_enabled') ? hash['automatic_extension_enabled'] : SKIP charge_request_notification_enabled = hash.key?('charge_request_notification_enabled') ? hash['charge_request_notification_enabled'] : SKIP charge_request_canceled_notification_enabled = hash.key?('charge_request_canceled_notification_enabled') ? hash['charge_request_canceled_notification_enabled'] : SKIP charge_expired_notification_enabled = hash.key?('charge_expired_notification_enabled') ? hash['charge_expired_notification_enabled'] : SKIP deposit_received_notification_enabled = hash.key?('deposit_received_notification_enabled') ? hash['deposit_received_notification_enabled'] : SKIP deposit_insufficient_notification_enabled = hash.key?('deposit_insufficient_notification_enabled') ? hash['deposit_insufficient_notification_enabled'] : SKIP deposit_exceeded_notification_enabled = hash.key?('deposit_exceeded_notification_enabled') ? hash['deposit_exceeded_notification_enabled'] : SKIP extension_notification_enabled = hash.key?('extension_notification_enabled') ? hash['extension_notification_enabled'] : SKIP remind_notification_period = hash.key?('remind_notification_period') ? hash['remind_notification_period'] : SKIP remind_notification_enabled = hash.key?('remind_notification_enabled') ? hash['remind_notification_enabled'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CheckoutBankTransferConfiguration.new(enabled: enabled, match_amount: match_amount, expiration: expiration, expiration_time_shift: expiration_time_shift, virtual_bank_accounts_threshold: virtual_bank_accounts_threshold, virtual_bank_accounts_fetch_count: virtual_bank_accounts_fetch_count, default_extension_period: default_extension_period, maximum_extension_period: maximum_extension_period, automatic_extension_enabled: automatic_extension_enabled, charge_request_notification_enabled: charge_request_notification_enabled, charge_request_canceled_notification_enabled: charge_request_canceled_notification_enabled, charge_expired_notification_enabled: charge_expired_notification_enabled, deposit_received_notification_enabled: deposit_received_notification_enabled, deposit_insufficient_notification_enabled: deposit_insufficient_notification_enabled, deposit_exceeded_notification_enabled: deposit_exceeded_notification_enabled, extension_notification_enabled: extension_notification_enabled, remind_notification_period: remind_notification_period, remind_notification_enabled: remind_notification_enabled, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 90 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['match_amount'] = 'match_amount' @_hash['expiration'] = 'expiration' @_hash['expiration_time_shift'] = 'expiration_time_shift' @_hash['virtual_bank_accounts_threshold'] = 'virtual_bank_accounts_threshold' @_hash['virtual_bank_accounts_fetch_count'] = 'virtual_bank_accounts_fetch_count' @_hash['default_extension_period'] = 'default_extension_period' @_hash['maximum_extension_period'] = 'maximum_extension_period' @_hash['automatic_extension_enabled'] = 'automatic_extension_enabled' @_hash['charge_request_notification_enabled'] = 'charge_request_notification_enabled' @_hash['charge_request_canceled_notification_enabled'] = 'charge_request_canceled_notification_enabled' @_hash['charge_expired_notification_enabled'] = 'charge_expired_notification_enabled' @_hash['deposit_received_notification_enabled'] = 'deposit_received_notification_enabled' @_hash['deposit_insufficient_notification_enabled'] = 'deposit_insufficient_notification_enabled' @_hash['deposit_exceeded_notification_enabled'] = 'deposit_exceeded_notification_enabled' @_hash['extension_notification_enabled'] = 'extension_notification_enabled' @_hash['remind_notification_period'] = 'remind_notification_period' @_hash['remind_notification_enabled'] = 'remind_notification_enabled' @_hash end |
.nullables ⇒ Object
An array for nullable fields
147 148 149 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 147 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 123 def self.optionals %w[ enabled match_amount expiration expiration_time_shift virtual_bank_accounts_threshold virtual_bank_accounts_fetch_count default_extension_period maximum_extension_period automatic_extension_enabled charge_request_notification_enabled charge_request_canceled_notification_enabled charge_expired_notification_enabled deposit_received_notification_enabled deposit_insufficient_notification_enabled deposit_exceeded_notification_enabled extension_notification_enabled remind_notification_period remind_notification_enabled ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 318 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, match_amount: #{@match_amount.inspect},"\ " expiration: #{@expiration.inspect}, expiration_time_shift:"\ " #{@expiration_time_shift.inspect}, virtual_bank_accounts_threshold:"\ " #{@virtual_bank_accounts_threshold.inspect}, virtual_bank_accounts_fetch_count:"\ " #{@virtual_bank_accounts_fetch_count.inspect}, default_extension_period:"\ " #{@default_extension_period.inspect}, maximum_extension_period:"\ " #{@maximum_extension_period.inspect}, automatic_extension_enabled:"\ " #{@automatic_extension_enabled.inspect}, charge_request_notification_enabled:"\ " #{@charge_request_notification_enabled.inspect},"\ ' charge_request_canceled_notification_enabled:'\ " #{@charge_request_canceled_notification_enabled.inspect},"\ " charge_expired_notification_enabled: #{@charge_expired_notification_enabled.inspect},"\ " deposit_received_notification_enabled: #{@deposit_received_notification_enabled.inspect},"\ ' deposit_insufficient_notification_enabled:'\ " #{@deposit_insufficient_notification_enabled.inspect},"\ " deposit_exceeded_notification_enabled: #{@deposit_exceeded_notification_enabled.inspect},"\ " extension_notification_enabled: #{@extension_notification_enabled.inspect},"\ " remind_notification_period: #{@remind_notification_period.inspect},"\ " remind_notification_enabled: #{@remind_notification_enabled.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/univapay_client_sdk/models/checkout_bank_transfer_configuration.rb', line 297 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, match_amount: #{@match_amount}, expiration:"\ " #{@expiration}, expiration_time_shift: #{@expiration_time_shift},"\ " virtual_bank_accounts_threshold: #{@virtual_bank_accounts_threshold},"\ " virtual_bank_accounts_fetch_count: #{@virtual_bank_accounts_fetch_count},"\ " default_extension_period: #{@default_extension_period}, maximum_extension_period:"\ " #{@maximum_extension_period}, automatic_extension_enabled:"\ " #{@automatic_extension_enabled}, charge_request_notification_enabled:"\ " #{@charge_request_notification_enabled}, charge_request_canceled_notification_enabled:"\ " #{@charge_request_canceled_notification_enabled}, charge_expired_notification_enabled:"\ " #{@charge_expired_notification_enabled}, deposit_received_notification_enabled:"\ " #{@deposit_received_notification_enabled}, deposit_insufficient_notification_enabled:"\ " #{@deposit_insufficient_notification_enabled}, deposit_exceeded_notification_enabled:"\ " #{@deposit_exceeded_notification_enabled}, extension_notification_enabled:"\ " #{@extension_notification_enabled}, remind_notification_period:"\ " #{@remind_notification_period}, remind_notification_enabled:"\ " #{@remind_notification_enabled}, additional_properties: #{@additional_properties}>" end |