Class: UnivapayClientSdk::TransactionTokensApi
- Defined in:
- lib/univapay_client_sdk/apis/transaction_tokens_api.rb
Overview
TransactionTokensApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#create_transaction_token(body, idempotency_key: nil) ⇒ ApiResponse
Exchange raw payment data for a secure token.
-
#delete_transaction_token(store_id, id) ⇒ ApiResponse
Deletes a specific transaction token.
-
#disable_token_three_ds(store_id, id) ⇒ ApiResponse
Disables 3-D Secure on an existing
recurringtransaction token. -
#enable_token_three_ds(store_id, id, idempotency_key: nil, body: nil) ⇒ ApiResponse
Enables 3-D Secure on an existing
recurringtransaction token that was created without it. -
#get_token_three_ds_issuer_token(store_id, id) ⇒ ApiResponse
Retrieves the information required to execute 3-D Secure authentication when creating a recurring transaction token.
-
#get_transaction_token(store_id, id, polling: nil) ⇒ ApiResponse
Retrieves the details of an existing transaction token.
-
#list_all_transaction_tokens(search: nil, customer_id: nil, type: nil, mode: nil, active: TransactionTokenActiveFilter::ACTIVE, limit: 10, cursor: nil, cursor_direction: CursorDirectionQuery::DESC) ⇒ ApiResponse
Lists all transaction tokens across all stores.
-
#list_store_transaction_tokens(store_id, search: nil, customer_id: nil, type: nil, mode: nil, active: TransactionTokenActiveFilter::ACTIVE, limit: 10, cursor: nil, cursor_direction: CursorDirectionQuery::DESC) ⇒ ApiResponse
Lists all transaction tokens for a specific store.
-
#update_transaction_token(store_id, id, idempotency_key: nil, body: nil) ⇒ ApiResponse
⚠️ LEGACY WARNING: Discouraged Operation While it is technically possible to update a transaction token, this practice is highly discouraged and is maintained solely for legacy reasons.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from UnivapayClientSdk::BaseApi
Instance Method Details
#create_transaction_token(body, idempotency_key: nil) ⇒ ApiResponse
Exchange raw payment data for a secure token. PCI DSS Compliance Required if sending raw card numbers. payload for creating a transaction token. idempotency key to prevent double charges and duplicate operations. We recommend a randomly generated UUID (v4).
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/univapay_client_sdk/apis/transaction_tokens_api.rb', line 17 def create_transaction_token(body, idempotency_key: nil) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/tokens', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter(idempotency_key, key: 'Idempotency-Key')) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Single.new('JWT_TOKEN'))) .response(new_response_handler .deserializer(proc do |response, should_symbolize| APIHelper.deserialize_union_type( UnionTypeLookUp.get(:TransactionToken), response, should_symbolize, true ) end) .is_api_response(true) .local_error_template('400', 'HTTP 400 Bad Request: {$response.body#/code}', ApiErrorException) .local_error_template('401', 'HTTP 401 Unauthorized: {$response.body#/code}', ApiErrorException) .local_error_template('403', 'HTTP 403 Forbidden: {$response.body#/code}', ApiErrorException) .local_error_template('429', 'HTTP 429 Rate Limited: {$response.body#/code}', APIException) .local_error_template('404', 'HTTP 404 Not Found: {$response.body#/code}', APIException) .local_error_template('409', 'HTTP 409 Conflict: {$response.body#/code}', APIException) .local_error_template('500', 'HTTP 500 Server Error: {$response.body#/code}', APIException) .local_error_template('503', 'HTTP 503 Unavailable: {$response.body#/code}', APIException) .local_error_template('504', 'HTTP 504 Timeout: {$response.body#/code}', APIException) .local_error_template('default', 'HTTP {$statusCode}: {$response.body#/code}', APIException)) .execute end |
#delete_transaction_token(store_id, id) ⇒ ApiResponse
Deletes a specific transaction token. ⚠️ WARNING: Breaks Linked Subscriptions Please note that deleting a transaction token will immediately prevent any linked recurring charges or subscriptions from being processed. Proceed with caution. of the store. resource.
394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/univapay_client_sdk/apis/transaction_tokens_api.rb', line 394 def delete_transaction_token(store_id, id) @api_call .request(new_request_builder(HttpMethodEnum::DELETE, '/stores/{storeId}/tokens/{id}', Server::DEFAULT) .template_param(new_parameter(store_id, key: 'storeId') .is_required(true) .should_encode(true)) .template_param(new_parameter(id, key: 'id') .is_required(true) .should_encode(true)) .auth(Single.new('JWT_TOKEN'))) .response(new_response_handler .is_response_void(true) .is_api_response(true) .local_error_template('400', 'HTTP 400 Bad Request: {$response.body#/code}', ApiErrorException) .local_error_template('401', 'HTTP 401 Unauthorized: {$response.body#/code}', ApiErrorException) .local_error_template('403', 'HTTP 403 Forbidden: {$response.body#/code}', ApiErrorException) .local_error_template('404', 'HTTP 404 Not Found: {$response.body#/code}', ApiErrorException) .local_error_template('429', 'HTTP 429 Rate Limited: {$response.body#/code}', APIException) .local_error_template('409', 'HTTP 409 Conflict: {$response.body#/code}', APIException) .local_error_template('500', 'HTTP 500 Server Error: {$response.body#/code}', APIException) .local_error_template('503', 'HTTP 503 Unavailable: {$response.body#/code}', APIException) .local_error_template('504', 'HTTP 504 Timeout: {$response.body#/code}', APIException) .local_error_template('default', 'HTTP {$statusCode}: {$response.body#/code}', APIException)) .execute end |
#disable_token_three_ds(store_id, id) ⇒ ApiResponse
Disables 3-D Secure on an existing recurring transaction token. Only
applies to recurring tokens.
of the store.
resource.
527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 |
# File 'lib/univapay_client_sdk/apis/transaction_tokens_api.rb', line 527 def disable_token_three_ds(store_id, id) @api_call .request(new_request_builder(HttpMethodEnum::DELETE, '/stores/{storeId}/tokens/{id}/three_ds', Server::DEFAULT) .template_param(new_parameter(store_id, key: 'storeId') .is_required(true) .should_encode(true)) .template_param(new_parameter(id, key: 'id') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('JWT_TOKEN'))) .response(new_response_handler .deserializer(proc do |response, should_symbolize| APIHelper.deserialize_union_type( UnionTypeLookUp.get(:TransactionToken), response, should_symbolize, true ) end) .is_api_response(true) .local_error_template('400', 'HTTP 400 Bad Request: {$response.body#/code}', ApiErrorException) .local_error_template('401', 'HTTP 401 Unauthorized: {$response.body#/code}', ApiErrorException) .local_error_template('403', 'HTTP 403 Forbidden: {$response.body#/code}', ApiErrorException) .local_error_template('404', 'HTTP 404 Not Found: {$response.body#/code}', ApiErrorException) .local_error_template('429', 'HTTP 429 Rate Limited: {$response.body#/code}', APIException) .local_error_template('409', 'HTTP 409 Conflict: {$response.body#/code}', APIException) .local_error_template('500', 'HTTP 500 Server Error: {$response.body#/code}', APIException) .local_error_template('503', 'HTTP 503 Unavailable: {$response.body#/code}', APIException) .local_error_template('504', 'HTTP 504 Timeout: {$response.body#/code}', APIException) .local_error_template('default', 'HTTP {$statusCode}: {$response.body#/code}', APIException)) .execute end |
#enable_token_three_ds(store_id, id, idempotency_key: nil, body: nil) ⇒ ApiResponse
Enables 3-D Secure on an existing recurring transaction token that was
created without it. Only applies to recurring tokens; returns an error
if 3DS is already enabled. After calling this endpoint, poll the token
until data.three_ds.status becomes awaiting, then use the token 3DS
issuer token endpoint to complete authentication.
of the store.
resource.
idempotency key to prevent double charges and duplicate operations. We
recommend a randomly generated UUID (v4).
request payload. Omit entirely, or omit redirect_endpoint, if no
redirect is needed.
459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/univapay_client_sdk/apis/transaction_tokens_api.rb', line 459 def enable_token_three_ds(store_id, id, idempotency_key: nil, body: nil) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/stores/{storeId}/tokens/{id}/three_ds', Server::DEFAULT) .template_param(new_parameter(store_id, key: 'storeId') .is_required(true) .should_encode(true)) .template_param(new_parameter(id, key: 'id') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .header_param(new_parameter(idempotency_key, key: 'Idempotency-Key')) .body_param(new_parameter(body)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Single.new('JWT_TOKEN'))) .response(new_response_handler .deserializer(proc do |response, should_symbolize| APIHelper.deserialize_union_type( UnionTypeLookUp.get(:TransactionToken), response, should_symbolize, true ) end) .is_api_response(true) .local_error_template('400', 'HTTP 400 Bad Request: {$response.body#/code}', ApiErrorException) .local_error_template('401', 'HTTP 401 Unauthorized: {$response.body#/code}', ApiErrorException) .local_error_template('403', 'HTTP 403 Forbidden: {$response.body#/code}', ApiErrorException) .local_error_template('404', 'HTTP 404 Not Found: {$response.body#/code}', ApiErrorException) .local_error_template('429', 'HTTP 429 Rate Limited: {$response.body#/code}', APIException) .local_error_template('409', 'HTTP 409 Conflict: {$response.body#/code}', APIException) .local_error_template('500', 'HTTP 500 Server Error: {$response.body#/code}', APIException) .local_error_template('503', 'HTTP 503 Unavailable: {$response.body#/code}', APIException) .local_error_template('504', 'HTTP 504 Timeout: {$response.body#/code}', APIException) .local_error_template('default', 'HTTP {$statusCode}: {$response.body#/code}', APIException)) .execute end |
#get_token_three_ds_issuer_token(store_id, id) ⇒ ApiResponse
Retrieves the information required to execute 3-D Secure authentication
when creating a recurring transaction token.
⚠️ Important Notes: 1. PCI DSS Compliance: This endpoint is only
available to PCI DSS compliant merchants who are authorized to send raw
card data directly via the API to create tokens. 2. Target Tokens:
This only applies to tokens where type is recurring. For one_time or
subscription tokens, 3-D Secure is requested during charge creation, not
token creation. 3. Execution Flow:
- After creating the token, poll the token object until
data.three_ds.statusbecomesawaiting. - Once
awaiting, use this endpoint to fetch the issuer token details. - Format the returned
payloadaccording to thecontent_type(e.g., URL-encoded) and execute anhttp_postrequest from the consumer's browser to theissuer_tokenURL. of the store. resource.
601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 |
# File 'lib/univapay_client_sdk/apis/transaction_tokens_api.rb', line 601 def get_token_three_ds_issuer_token(store_id, id) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/stores/{storeId}/tokens/{id}/three_ds/issuer_token', Server::DEFAULT) .template_param(new_parameter(store_id, key: 'storeId') .is_required(true) .should_encode(true)) .template_param(new_parameter(id, key: 'id') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('JWT_TOKEN'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ThreeDsIssuerToken.method(:from_hash)) .is_api_response(true) .local_error_template('400', 'HTTP 400 Bad Request: {$response.body#/code}', ApiErrorException) .local_error_template('401', 'HTTP 401 Unauthorized: {$response.body#/code}', ApiErrorException) .local_error_template('403', 'HTTP 403 Forbidden: {$response.body#/code}', ApiErrorException) .local_error_template('404', 'HTTP 404 Not Found: {$response.body#/code}', ApiErrorException) .local_error_template('429', 'HTTP 429 Rate Limited: {$response.body#/code}', APIException) .local_error_template('409', 'HTTP 409 Conflict: {$response.body#/code}', APIException) .local_error_template('500', 'HTTP 500 Server Error: {$response.body#/code}', APIException) .local_error_template('503', 'HTTP 503 Unavailable: {$response.body#/code}', APIException) .local_error_template('504', 'HTTP 504 Timeout: {$response.body#/code}', APIException) .local_error_template('default', 'HTTP {$statusCode}: {$response.body#/code}', APIException)) .execute end |
#get_transaction_token(store_id, id, polling: nil) ⇒ ApiResponse
Retrieves the details of an existing transaction token. of the store. resource. true, instructs the API to internally poll the token's 3DS or CVV authorization sub-status until it transitions to another status, or until the ~3 second server-side timeout is reached.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/univapay_client_sdk/apis/transaction_tokens_api.rb', line 241 def get_transaction_token(store_id, id, polling: nil) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/stores/{storeId}/tokens/{id}', Server::DEFAULT) .template_param(new_parameter(store_id, key: 'storeId') .is_required(true) .should_encode(true)) .template_param(new_parameter(id, key: 'id') .is_required(true) .should_encode(true)) .query_param(new_parameter(polling, key: 'polling')) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('JWT_TOKEN'))) .response(new_response_handler .deserializer(proc do |response, should_symbolize| APIHelper.deserialize_union_type( UnionTypeLookUp.get(:TransactionToken), response, should_symbolize, true ) end) .is_api_response(true) .local_error_template('400', 'HTTP 400 Bad Request: {$response.body#/code}', ApiErrorException) .local_error_template('401', 'HTTP 401 Unauthorized: {$response.body#/code}', ApiErrorException) .local_error_template('403', 'HTTP 403 Forbidden: {$response.body#/code}', ApiErrorException) .local_error_template('404', 'HTTP 404 Not Found: {$response.body#/code}', ApiErrorException) .local_error_template('429', 'HTTP 429 Rate Limited: {$response.body#/code}', APIException) .local_error_template('409', 'HTTP 409 Conflict: {$response.body#/code}', APIException) .local_error_template('500', 'HTTP 500 Server Error: {$response.body#/code}', APIException) .local_error_template('503', 'HTTP 503 Unavailable: {$response.body#/code}', APIException) .local_error_template('504', 'HTTP 504 Timeout: {$response.body#/code}', APIException) .local_error_template('default', 'HTTP {$statusCode}: {$response.body#/code}', APIException)) .execute end |
#list_all_transaction_tokens(search: nil, customer_id: nil, type: nil, mode: nil, active: TransactionTokenActiveFilter::ACTIVE, limit: 10, cursor: nil, cursor_direction: CursorDirectionQuery::DESC) ⇒ ApiResponse
Lists all transaction tokens across all stores.
search.
ID.
type. one_time tokens are excluded from listings and cannot be filtered
on; filtering to recurring requires the App Token Secret.
recurring tokens by whether they are still active.
return in one page.
resource after which pagination should continue.
Pagination direction relative to the supplied cursor.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/univapay_client_sdk/apis/transaction_tokens_api.rb', line 89 def list_all_transaction_tokens(search: nil, customer_id: nil, type: nil, mode: nil, active: TransactionTokenActiveFilter::ACTIVE, limit: 10, cursor: nil, cursor_direction: CursorDirectionQuery::DESC) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/tokens', Server::DEFAULT) .query_param(new_parameter(search, key: 'search')) .query_param(new_parameter(customer_id, key: 'customer_id')) .query_param(new_parameter(type, key: 'type')) .query_param(new_parameter(mode, key: 'mode')) .query_param(new_parameter(active, key: 'active')) .query_param(new_parameter(limit, key: 'limit')) .query_param(new_parameter(cursor, key: 'cursor')) .query_param(new_parameter(cursor_direction, key: 'cursor_direction')) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('JWT_TOKEN'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(TransactionTokenList.method(:from_hash)) .is_api_response(true) .local_error_template('400', 'HTTP 400 Bad Request: {$response.body#/code}', ApiErrorException) .local_error_template('401', 'HTTP 401 Unauthorized: {$response.body#/code}', ApiErrorException) .local_error_template('403', 'HTTP 403 Forbidden: {$response.body#/code}', ApiErrorException) .local_error_template('429', 'HTTP 429 Rate Limited: {$response.body#/code}', APIException) .local_error_template('404', 'HTTP 404 Not Found: {$response.body#/code}', APIException) .local_error_template('409', 'HTTP 409 Conflict: {$response.body#/code}', APIException) .local_error_template('500', 'HTTP 500 Server Error: {$response.body#/code}', APIException) .local_error_template('503', 'HTTP 503 Unavailable: {$response.body#/code}', APIException) .local_error_template('504', 'HTTP 504 Timeout: {$response.body#/code}', APIException) .local_error_template('default', 'HTTP {$statusCode}: {$response.body#/code}', APIException)) .execute end |
#list_store_transaction_tokens(store_id, search: nil, customer_id: nil, type: nil, mode: nil, active: TransactionTokenActiveFilter::ACTIVE, limit: 10, cursor: nil, cursor_direction: CursorDirectionQuery::DESC) ⇒ ApiResponse
Lists all transaction tokens for a specific store.
of the store.
search.
ID.
type. one_time tokens are excluded from listings and cannot be filtered
on; filtering to recurring requires the App Token Secret.
recurring tokens by whether they are still active.
return in one page.
resource after which pagination should continue.
Pagination direction relative to the supplied cursor.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/univapay_client_sdk/apis/transaction_tokens_api.rb', line 168 def list_store_transaction_tokens(store_id, search: nil, customer_id: nil, type: nil, mode: nil, active: TransactionTokenActiveFilter::ACTIVE, limit: 10, cursor: nil, cursor_direction: CursorDirectionQuery::DESC) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/stores/{storeId}/tokens', Server::DEFAULT) .template_param(new_parameter(store_id, key: 'storeId') .is_required(true) .should_encode(true)) .query_param(new_parameter(search, key: 'search')) .query_param(new_parameter(customer_id, key: 'customer_id')) .query_param(new_parameter(type, key: 'type')) .query_param(new_parameter(mode, key: 'mode')) .query_param(new_parameter(active, key: 'active')) .query_param(new_parameter(limit, key: 'limit')) .query_param(new_parameter(cursor, key: 'cursor')) .query_param(new_parameter(cursor_direction, key: 'cursor_direction')) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('JWT_TOKEN'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(TransactionTokenList.method(:from_hash)) .is_api_response(true) .local_error_template('400', 'HTTP 400 Bad Request: {$response.body#/code}', ApiErrorException) .local_error_template('401', 'HTTP 401 Unauthorized: {$response.body#/code}', ApiErrorException) .local_error_template('403', 'HTTP 403 Forbidden: {$response.body#/code}', ApiErrorException) .local_error_template('429', 'HTTP 429 Rate Limited: {$response.body#/code}', APIException) .local_error_template('404', 'HTTP 404 Not Found: {$response.body#/code}', APIException) .local_error_template('409', 'HTTP 409 Conflict: {$response.body#/code}', APIException) .local_error_template('500', 'HTTP 500 Server Error: {$response.body#/code}', APIException) .local_error_template('503', 'HTTP 503 Unavailable: {$response.body#/code}', APIException) .local_error_template('504', 'HTTP 504 Timeout: {$response.body#/code}', APIException) .local_error_template('default', 'HTTP {$statusCode}: {$response.body#/code}', APIException)) .execute end |
#update_transaction_token(store_id, id, idempotency_key: nil, body: nil) ⇒ ApiResponse
⚠️ LEGACY WARNING: Discouraged Operation
While it is technically possible to update a transaction token, this
practice is highly discouraged and is maintained solely for legacy
reasons.
Updating raw card details requires your server environment to be fully
PCI DSS compliant.
Recommended Approach: Instead of updating an existing token, it is
best practice to create an entirely new transaction token using Univapay's
frontend integrations (Link Form, Widget, or Inline Form).
This allows Univapay to securely handle the customer's payment data
without it ever touching your servers.
--- Legacy Usage: Updates CVV, Address, Email, or Card Details.
Note: If updating only the CVV to resolve a
RECURRING_USAGE_REQUIRES_CVV error, the application token secret is not
required.
of the store.
resource.
idempotency key to prevent double charges and duplicate operations. We
recommend a randomly generated UUID (v4).
payload for updating a transaction token.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/univapay_client_sdk/apis/transaction_tokens_api.rb', line 323 def update_transaction_token(store_id, id, idempotency_key: nil, body: nil) @api_call .request(new_request_builder(HttpMethodEnum::PATCH, '/stores/{storeId}/tokens/{id}', Server::DEFAULT) .template_param(new_parameter(store_id, key: 'storeId') .is_required(true) .should_encode(true)) .template_param(new_parameter(id, key: 'id') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .header_param(new_parameter(idempotency_key, key: 'Idempotency-Key')) .body_param(new_parameter(body)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Single.new('JWT_TOKEN'))) .response(new_response_handler .deserializer(proc do |response, should_symbolize| APIHelper.deserialize_union_type( UnionTypeLookUp.get(:TransactionToken), response, should_symbolize, true ) end) .is_api_response(true) .local_error_template('400', 'HTTP 400 Bad Request: {$response.body#/code}', ApiErrorException) .local_error_template('401', 'HTTP 401 Unauthorized: {$response.body#/code}', ApiErrorException) .local_error_template('403', 'HTTP 403 Forbidden: {$response.body#/code}', ApiErrorException) .local_error_template('404', 'HTTP 404 Not Found: {$response.body#/code}', ApiErrorException) .local_error_template('429', 'HTTP 429 Rate Limited: {$response.body#/code}', APIException) .local_error_template('409', 'HTTP 409 Conflict: {$response.body#/code}', APIException) .local_error_template('500', 'HTTP 500 Server Error: {$response.body#/code}', APIException) .local_error_template('503', 'HTTP 503 Unavailable: {$response.body#/code}', APIException) .local_error_template('504', 'HTTP 504 Timeout: {$response.body#/code}', APIException) .local_error_template('default', 'HTTP {$statusCode}: {$response.body#/code}', APIException)) .execute end |